api

package
v0.0.0-...-af1d8da Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2025 License: BSD-2-Clause Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DsnApi

type DsnApi struct {
}

func (*DsnApi) ExecCmd

func (api *DsnApi) ExecCmd(c *gin.Context)

ExecCmd godoc @Summary Execute a sql command @Description Execute a sql command with the given parameters @Tags Dsn Hun Client @Accept json @Produce json @Param func_name path string true "Function Name" @Param params path object true "Function Parameters (as a map)" @Success 200 {object} []map[string]interface{} "Successful operation" @Failure 400 {object} proto.ResponseMsg "Failed operation" @Router /dsn/exec/{func_name}/{params} [get]

func (*DsnApi) ExecSql

func (api *DsnApi) ExecSql(c *gin.Context)

func (*DsnApi) GetFuncList

func (api *DsnApi) GetFuncList(c *gin.Context)

GetFuncList godoc @Summary Get func list for dsn hub client @Description Retrieve the list of functions that can be executed @Tags Dsn Hun Client @Produce json @Success 200 {object} []map[string]string "Successful operation" @Failure 400 {object} proto.ResponseMsg "Failed operation" @Router /dsn/func_list [get]

func (*DsnApi) LoadSqlFile

func (api *DsnApi) LoadSqlFile(c *gin.Context)

type LoadRequest

type LoadRequest struct {
	TomlPath string `json:"toml_path" binding:"required"`
}

type SqlRequest

type SqlRequest struct {
	FuncName string `json:"func_name" binding:"required"`
	Params   string `json:"params"`
}

Jump to